/*!\file: balancevelocities_core.cpp
 * \brief: core of the balancevelocities solution 
 */ 

#include "../toolkits/toolkits.h"
#include "../objects/objects.h"
#include "../shared/shared.h"
#include "../EnumDefinitions/EnumDefinitions.h"
#include "./solutions.h"
#include "../modules/modules.h"
#include "../solvers/solvers.h"

void balancevelocities_core(FemModel* femmodel){

	/*flags: */
	int  dim;
	bool control_analysis;
	int  solution_type;

	/*activate formulation: */
	femmodel->SetCurrentConfiguration(BalancevelocitiesAnalysisEnum);
	
	/*recover parameters: */
	femmodel->parameters->FindParam(&dim,DimEnum);
	femmodel->parameters->FindParam(&control_analysis,ControlAnalysisEnum);
	femmodel->parameters->FindParam(&solution_type,SolutionTypeEnum);

	_printf_(VerboseSolution(),"   call computational core\n");
	solver_linear(femmodel);

	if(solution_type==BalancevelocitiesSolutionEnum && !control_analysis){
		_printf_(VerboseSolution(),"   saving results\n");
		InputToResultx(femmodel->elements,femmodel->nodes,femmodel->vertices,femmodel->loads,femmodel->materials,femmodel->parameters,VelEnum);
	}

}
